==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ar.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "لوحة التحكم",
    "Dashboard app" : "تطبيق لوحة التحكم",
    "Show something" : "أظهر شي ما",
    "Customize" : "تعديل",
    "Edit widgets" : "تعديل الودجات",
    "Get more widgets from the app store" : "احصل على ودجات من متجر التطبيقات",
    "Change background image" : "تغييرصورة الخلفية",
    "Weather service" : "خدمة احوال الطقس",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "لخصوصيتك، يتم استدعاء بيانات احوال الطقس عبر خادم نكست كلاود الخاص بك نيابه عنك ولذلك خدمة احوال الطقس لا تشارك المعلومات الشخصية.",
    "Weather data from Met.no" : "بيانات احوال الطقس من Met.no",
    "geocoding with Nominatim" : "الترميز الجغرافي مع Nominatim",
    "elevation data from OpenTopoData" : "بيانات التقييم من OpenTopoData",
    "Weather" : "الطقس",
    "Status" : "الحالة",
    "Good evening, {name}" : "مساء الخير، {name}",
    "Good evening" : "مساء الخير",
    "Good afternoon, {name}" : "مساء الخير، {name}",
    "Good afternoon" : "مساء الخير",
    "Good morning, {name}" : "صباح الخير ، {name}",
    "Good morning" : "صباح الخير",
    "Good night, {name}" : "تصبح على خير، {name}",
    "Good night" : "تصبح على خير",
    "Pick from files" : "اختر من الملفات",
    "Default images" : "الصور الإفتراضية",
    "Plain background" : "خلفية سادة",
    "Insert from {productName}" : "اضف من {productName}"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-21.0.0-9-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/ar.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "لوحة التحكم",
    "Dashboard app" : "تطبيق لوحة التحكم",
    "Show something" : "أظهر شي ما",
    "Customize" : "تعديل",
    "Edit widgets" : "تعديل الودجات",
    "Get more widgets from the app store" : "احصل على ودجات من متجر التطبيقات",
    "Change background image" : "تغييرصورة الخلفية",
    "Weather service" : "خدمة احوال الطقس",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "لخصوصيتك، يتم استدعاء بيانات احوال الطقس عبر خادم نكست كلاود الخاص بك نيابه عنك ولذلك خدمة احوال الطقس لا تشارك المعلومات الشخصية.",
    "Weather data from Met.no" : "بيانات احوال الطقس من Met.no",
    "geocoding with Nominatim" : "الترميز الجغرافي مع Nominatim",
    "elevation data from OpenTopoData" : "بيانات التقييم من OpenTopoData",
    "Weather" : "الطقس",
    "Status" : "الحالة",
    "Good morning" : "صباح الخير",
    "Good morning, {name}" : "صباح الخير ، {name}",
    "Good afternoon" : "مساء الخير",
    "Good afternoon, {name}" : "مساء الخير، {name}",
    "Good evening" : "مساء الخير",
    "Good evening, {name}" : "مساء الخير، {name}",
    "Default images" : "الصور الإفتراضية",
    "Plain background" : "خلفية سادة",
    "Insert from {productName}" : "اضف من {productName}",
    "Good night, {name}" : "تصبح على خير، {name}",
    "Good night" : "تصبح على خير",
    "Pick from files" : "اختر من الملفات"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
